@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10389 2017-10-22 05:43:34Z Lavender $
+# $Id: __init__.py 10552 2017-11-26 08:30:27Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,11 +12,12 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2017-10-22 13:43:34 +0800 (週日, 22 十月 2017) $
-# $Revision: 10389 $
+# $Date: 2017-11-26 16:30:27 +0800 (週日, 26 十一月 2017) $
+# $Revision: 10552 $
 
 import os
 import warnings
+import logging
 
 # from django.utils.translation import ugettext_lazy as _
 
@@ -27,6 +28,18 @@ import warnings
 from Iuppiter.Util import extendUnique
 from Iuppiter.DjangoUtil import extendInstalledApps
 
+def createLogger(name, fileHandlerName):
+    logger = logging.getLogger(name)
+    logger.setLevel(logging.DEBUG)
+    handler = logging.StreamHandler()
+    handler.setFormatter(
+        logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
+    logger.addHandler(handler)
+    fileHandler = logging.FileHandler(fileHandlerName)
+    fileHandler.setLevel(logging.WARNING)
+    logger.addHandler(fileHandler)
+    return logger
+
 def update(settingsDict, defaults, config=None):
     """
     Update settings by defaults if the key is not in settings.
@@ -65,6 +78,8 @@ def attachSettings(settingsDict):
         'Zephyrus.boilerplate',
         'Zephyrus.landing',
         'Zephyrus.facebook',
+        'drip',
+        'Zephyrus.drip2',
     )
 
     installed = settingsDict['INSTALLED_APPS']
