@@ -24,7 +24,9 @@ from lxml import etree
 from lxml.html import soupparser
 from lxml.html.soupparser import parse
 from django.core.management.base import BaseCommand
+from django.conf import settings
 from django.template.loader import get_template
+from django.template import Context
 from BeautifulSoup import (
         BeautifulSoup, Tag, Comment, ProcessingInstruction, NavigableString,
         Declaration, CData)
@@ -40,7 +42,7 @@ soupparser.CData = CData
 soupparser._DECLARATION_OR_DOCTYPE = _DECLARATION_OR_DOCTYPE
 
 from Zephyrus.boilerplate.management.commands import (
-    TEMPLATES_DIR_PATH, STATIC_DIR_PATH)
+    TEMPLATES_DIR_PATH, STATIC_DIR_PATH, ROOT_DIR_PATH)
 from Zephyrus.boilerplate.management.commands import createLogger
 
 logger = createLogger(__name__, "BuildBoilerplate2.log")
@@ -79,6 +81,7 @@ CHANGE_WORD = {
     '}': '&#125;',
     '&#123;': '&#123;',
     '&#125;': '&#125;',
+    '&amp;': '&',
 }
 EXCEPT_TAGS = ['nav', 'section', ]
 NO_INDENT = ['pre', 'code',]
@@ -478,6 +481,39 @@ class Command(BaseCommand):
             head.text = ''
         head.text = '\n' + CMS_HEAD_FRONT_TAG + head.text
 
+        # google analytics
+        if os.path.isfile(os.path.join(ROOT_DIR_PATH, 'info.json')):
+            with open(os.path.join(ROOT_DIR_PATH, 'info.json')) as jsonfile:
+                data = json.load(jsonfile)
+            upc = data['upc']
+            
+            # comment
+            analyticsComment = etree.Comment(
+                text=get_template(
+                    'boilerplate/txt/analyticsComment.txt').render())
+
+            # iframe
+            analyticsIframe = etree.Element('iframe')
+            url = get_template(
+                    'boilerplate/txt/analyticsUrl.txt').render()
+            analyticUrl = \
+                "%s?upc=%s&complexity=CMS_PLUGINIZE_REPLACE" % (url, upc)
+
+            analyticsIframe.set('src', analyticUrl)
+            analyticsIframe.set('name', "_themes_tracking")
+            analyticsIframe.set('width', "1")
+            analyticsIframe.set('height', "1")
+            analyticsIframe.set('marginwidth', "0")
+            analyticsIframe.set('marginheight', "0")
+            analyticsIframe.set('align', "top")
+            analyticsIframe.set('scrolling', "No")
+            analyticsIframe.set('frameborder', "0")
+            analyticsIframe.set('hspace', "0")
+            analyticsIframe.set('vspace', "0")
+
+            body.append(analyticsComment)
+            body.append(analyticsIframe)
+
         # add cms data to body
         if body.getchildren():
             if body[-1].tail is None:
