@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_templates.py 10541 2017-11-21 10:42:06Z Lavender $
+# $Id: build_templates.py 10550 2017-11-26 06:14:06Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-11-21 18:42:06 +0800 (週二, 21 十一月 2017) $
-# $Revision: 10541 $
+# $Date: 2017-11-26 14:14:06 +0800 (週日, 26 十一月 2017) $
+# $Revision: 10550 $
 
 import os
 import sys
@@ -44,6 +44,8 @@ class Command(BaseCommand):
     def handle(self, *args, **options):
         startPath = options['start']
         dstPath = options['output']
+
+        hasError = 0
         
         for f in os.listdir(startPath):
             tempPath = os.path.join(startPath, f)
@@ -65,6 +67,7 @@ class Command(BaseCommand):
                 logger.error(
                     "get_template error code: %d, from template: %s" % 
                     (error, tempPath))
+                hasError = 1
                 continue
 
             # build_boilerplate
@@ -75,6 +78,7 @@ class Command(BaseCommand):
                 logger.error(
                     "build_boilerplate error code: %d, from template: %s" % 
                     (error, tempPath))
+                hasError = 1
                 continue
                 
             # create_pages
@@ -84,6 +88,7 @@ class Command(BaseCommand):
                 logger.error(
                     "create_pages error code: %d, from template: %s" % 
                     (error, tempPath))
+                hasError = 1
                 continue
                 
             # pluginize
@@ -93,6 +98,7 @@ class Command(BaseCommand):
                 logger.error(
                     "pluginize error code: %d, from template: %s" % 
                     (error, tempPath))
+                hasError = 1
                 continue
                 
             # fix_template
@@ -102,6 +108,7 @@ class Command(BaseCommand):
                 logger.error(
                     "fix_template error code: %d, from template: %s" % 
                     (error, tempPath))
+                hasError = 1
                 continue
 
             # dumpdata
@@ -113,6 +120,7 @@ class Command(BaseCommand):
                 logger.error(
                     "dumpdata error code: %d, from template: %s" % 
                     (error, tempPath))
+                hasError = 1
                 continue
 
             # create_zip
@@ -127,5 +135,8 @@ class Command(BaseCommand):
                 logger.error(
                     "create_zip error code: %d, from template: %s" % 
                     (error, tempPath))
+                hasError = 1
                 continue
+        
+        return hasError
             
\ No newline at end of file
