@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 10368 2017-10-13 11:25:36Z Lavender $
+# $Id: setup.py 10554 2017-11-26 13:21:13Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-10-13 19:25:36 +0800 (週五, 13 十月 2017) $
-# $Revision: 10368 $ 
+# $Date: 2017-11-26 21:21:13 +0800 (週日, 26 十一月 2017) $
+# $Revision: 10554 $ 
 
 import os
 import sys
@@ -213,7 +213,11 @@ if __name__ == "__main__":
         try:
             import djangocms_installer
         except Exception as e:
-            os.system("pip install djangocms-installer")
+            result = os.system("pip install djangocms-installer")
+            if result != 0:
+                logger.error(
+                    "Please check network is connect or pip is enable.")
+                sys.exit()
         
         if sys.version_info.major == 3:
             projectName = input(
